@@ -58,11 +58,15 @@ class AuthenticateMiddleware:
     def _provider_claims(self, provider, token):
         """
         Validates the token and returns its respective claims against a specific provider.
+
+        The ``at_hash`` value in the token, if present, is ignored, because in order to
+        verify it, the access token would be required, which we don't have access to.
         """
         return jose.jwt.decode(
             token, self._provider_keys(provider),
             issuer=self._providers[provider]['issuer'],
             audience=self._providers[provider]['audience'],
+            options={'verify_at_hash': False}  # Ignore at_hash, if present
         )
 
     def claims(self, token: str):
